set -e
BASEDIR=$(dirname "$0")

################################################################
# Please modify the next paths:
LLVM_LINK="$BASEDIR/../llvm-link"
DSYMUTIL="$BASEDIR/../dsymutil"
XCODE="/Applications/Xcode 12.5.app"
################################################################

OUTPUTS="$BASEDIR/outputs"

echo "Cleaning"

rm -f -R "$OUTPUTS"
mkdir -p "$OUTPUTS"

echo "swiftc"

BC_FILES=()

function compile() {
    FILE=$1
    BASE=`basename $1 .bc`
    "$XCODE/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/swift-frontend" -frontend \
        -primary-file "$FILE" \
        -emit-bc \
        -embed-bitcode \
        -target arm64-apple-ios12.0 \
        -Xllvm -aarch64-use-tbi -Osize -disable-llvm-optzns \
        -module-name Swinject \
        -o "$OUTPUTS/$BASE.bc"
    BC_FILES+=("$OUTPUTS/$BASE.bc")
}

for FILE in $BASEDIR/bc/*.*; do
    echo "Compiling $FILE"
    compile $FILE
done

echo "llvm-link"

"$LLVM_LINK" "${BC_FILES[@]}" -o "$OUTPUTS/app.ll"

echo "clang"

echo "$OUTPUTS/app.ll" > "$OUTPUTS/DummyWWDC.LinkFileList"

"$XCODE/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/bin/clang" \
    -target arm64-apple-ios12.0 \
    -isysroot "$XCODE/Contents/Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS14.5.sdk" \
    -filelist "$OUTPUTS/DummyWWDC.LinkFileList" \
    -Xlinker -object_path_lto -Xlinker $OUTPUTS/JardinDeJuegos_lto.o \
    -fembed-bitcode -Xlinker -bitcode_verify -Xlinker -bitcode_hide_symbols \
    -L"$XCODE/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/swift/iphoneos" \
    -L/usr/lib/swift \
    -o "$OUTPUTS/DummyWWDC"

echo "dsymutil"

"$DSYMUTIL" "$OUTPUTS/DummyWWDC" -o "$OUTPUTS/DummyWWDC.dSYM"

dwarfdump -verify "$OUTPUTS/DummyWWDC.dSYM"
